package com.xmlmind.whc;

/**
 * A strong 64-bit hash function in Java.
 * @see <a href="https://www.javamex.com/tutorials/collections/strong_hash_code.shtml">A strong 64-bit hash function in Java</a>
 */

/*package*/ final class Hash64 {
    private static final long HSTART = 0xBB40E64DA205B064L;
    private static final long HMULT = 7664345821815920749L;
    private static final long[] byteTable = new long[256];
    static {
        long h = 0x544B2FBACAAF1684L;
        for (int i = 0; i < 256; i++) {
            for (int j = 0; j < 31; j++) {
                h = (h >>> 7) ^ h;
                h = (h << 11) ^ h;
                h = (h >>> 10) ^ h;
            }
            byteTable[i] = h;
        }
    }

    /*
    public static long hash(byte[] data) {
        long h = HSTART;
        final long hmult = HMULT;
        final long[] ht = byteTable;
        for (int len = data.length, i = 0; i < len; i++) {
            h = (h * hmult) ^ ht[data[i] & 0xff];
        }
        return h;
    }
    */

    public static long hash(CharSequence cs) {
        long h = HSTART;
        final long hmult = HMULT;
        final long[] ht = byteTable;
        final int len = cs.length();
        for (int i = 0; i < len; i++) {
            char ch = cs.charAt(i);
            h = (h * hmult) ^ ht[ch & 0xff];
            h = (h * hmult) ^ ht[(ch >>> 8) & 0xff];
        }
        return h;
    }

    /*TEST_HASH64
    public static void main(String[] args) {
        for (String arg : args) {
            System.out.println("'" + arg + "' --> " + 
                               Long.toString(Hash64.hash(arg),
                                             Character.MAX_RADIX));
        }
    }
    TEST_HASH64*/
}
