/*
 * Copyright (c) 2017-2020 XMLmind Software. All rights reserved.
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind Web Help Compiler project.
 * For conditions of distribution and use, see the accompanying LEGAL.txt file.
 */
package com.xmlmind.whc;

import org.tartarus.snowball.SnowballStemmer;

/*package*/ final class Stemmer {
    public final String langCode;
    public final String langName;
    private final SnowballStemmer stemmer;
    
    private static final String[] LANGUAGES = {
        "arabic",     "ar",
        "basque",     "eu",
        "catalan",    "ca",
        "danish",     "da",
        "dutch",      "nl",
        "english",    "en",
        "finnish",    "fi",
        "french",     "fr",
        "german",     "de",
        "greek",      "el",
        "hindi",      "hi",
        "hungarian",  "hu",
        "indonesian", "id",
        "irish",      "ga",
        "italian",    "it",
        "lithuanian", "lt",
        "nepali",     "ne",
        "norwegian",  "no",
        "portuguese", "pt",
        "romanian",   "ro",
        "russian",    "ru",
        "serbian",    "sr",
        "spanish",    "es",
        "swedish",    "sv",
        "tamil",      "ta",
        "turkish",    "tr"
    };

    // -----------------------------------------------------------------------

    public static Stemmer create(String langCode) {
        String langName = null;
        if (langCode != null) {
            if (langCode.length() > 2) {
                langCode = langCode.substring(0, 2);
            }
            langCode = langCode.toLowerCase();

            for (int i = 0; i < LANGUAGES.length; i += 2) {
                if (LANGUAGES[i+1].equals(langCode)) {
                    langName = LANGUAGES[i];
                    break;
                }
            }
        }

        SnowballStemmer stemmer = null;
        if (langName != null) {
            try {
                stemmer = (SnowballStemmer) 
                    Class.forName("org.tartarus.snowball.ext." + 
                                  langName + "Stemmer")
                    .getDeclaredConstructor().newInstance();
            } catch (Throwable ignored) {}
        }

        if (stemmer != null) {
            return new Stemmer(langCode, langName, stemmer);
        } else {
            return null;
        }
    }

    private Stemmer(String langCode, String langName, SnowballStemmer stemmer) {
        this.langCode = langCode;
        this.langName = langName;
        this.stemmer = stemmer;
    }

    public String stem(String word) {
        stemmer.setCurrent(word);
        stemmer.stem();
        return stemmer.getCurrent();
    }
}
